-- CREATE DATABASE OBSLOG
-- 2016-09-18

-- Copyright 2016 Hernán De Angelis
-- 
-- Licensed under the Apache License, Version 2.0 (the "License");
-- you may not use this file except in compliance with the License.
-- You may obtain a copy of the License at
-- 
--     http://www.apache.org/licenses/LICENSE-2.0
-- 
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS,
-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-- See the License for the specific language governing permissions and
-- limitations under the License.


BEGIN;

PRAGMA foreign_keys = ON;

-- CENTRAL TABLES

-- session 
CREATE TABLE session (
sessionID integer NOT NULL PRIMARY KEY AUTOINCREMENT,
sessionSite text,
sessionDateTimeStart text,
sessionDateTimeEnd text,
sessionSummerTime boolean,
sessionTempC real,
sessionRHproc real,
sessionWindSpeedMS real,
sessionWindDirAz real,
sessionCloudFraction real,
sessionCloudType text,
sessionSeeingAnt integer,
sessionTransparency integer,
sessionMoonPhase real,
sessionNotes text,
FOREIGN KEY (sessionSite) REFERENCES site(siteID)
);
-- sessionTransparency: defined in scale from 1 to 5, where:
-- 1: poor
-- 2: acceptable
-- 3: good
-- 4: very good
-- 5: excellent


-- observation log
CREATE TABLE obslog (
obsID integer NOT NULL PRIMARY KEY AUTOINCREMENT,
obsSession integer,
obsDateTimeLocal text,
obsObject text,
obsNotes text,
obsSketch text,
obsInstrument text,
obsMount text,
obsEyepiece text,
obsLens text,
obsFilter text,
obsAccessory text,
FOREIGN KEY (obsSession) REFERENCES session(sessionID),
FOREIGN KEY (obsObject) REFERENCES object(objectMyName),
FOREIGN KEY (obsInstrument) REFERENCES instrument(instrumentID),
FOREIGN KEY (obsMount) REFERENCES mount(mountID),
FOREIGN KEY (obsEyepiece) REFERENCES eyepiece(eyepieceID),
FOREIGN KEY (obsLens) REFERENCES lens(lensID),
FOREIGN KEY (obsFilter) REFERENCES filter(filterID),
FOREIGN KEY (obsAccessory) REFERENCES accessory(accessoryID)
);

-- imaging log
CREATE TABLE imglog (
imgID integer NOT NULL PRIMARY KEY AUTOINCREMENT,
imgSession integer,
imgDateTimeStart text,
imgDateTimeEnd text,
imgObject text,
imgNotes text,
imgFlats integer,
imgDarks integer,
imgBias integer,
imgLights integer,
imgCamera text,
imgISO integer,
imgExpTime integer,
imgInstrument text,
imgMount text,
imgEyepiece text,
imgLens text,
imgFilter text,
imgAccessory text,
FOREIGN KEY (imgSession) REFERENCES session(sessionID),
FOREIGN KEY (imgObject) REFERENCES object(objectMyName),
FOREIGN KEY (imgCamera) REFERENCES camera(cameraID),
FOREIGN KEY (imgInstrument) REFERENCES instrument(instrumentID),
FOREIGN KEY (imgMount) REFERENCES mount(mountID),
FOREIGN KEY (imgEyepiece) REFERENCES eyepiece(eyepieceID),
FOREIGN KEY (imgLens) REFERENCES lens(lensID),
FOREIGN KEY (imgFilter) REFERENCES filter(filterID),
FOREIGN KEY (imgAccessory) REFERENCES accessory(accessoryID)
);

-- visual variable star observation log
CREATE TABLE varstarlog (
obsID integer NOT NULL PRIMARY KEY AUTOINCREMENT,
obsSession integer,
obsDateTimeLocal text,
obsTargetStar text,
obsCompStar1 real,
obsCompStar2 real,
obsTargetStarEstimate real,
obsTargetStarEstimateError real,
obsFainterThan boolean,
obsEstimationMethod text,
obsAAVSOchart text,
obsAAVSOcomment text,
obsNotes text,
obsInstrument text,
obsMount text,
obsEyepiece text,
obsLens text,
obsFilter text,
obsAccessory text,
FOREIGN KEY (obsSession) REFERENCES session(sessionID),
FOREIGN KEY (obsTargetStar) REFERENCES object(objectMyName),
FOREIGN KEY (obsInstrument) REFERENCES instrument(instrumentID),
FOREIGN KEY (obsMount) REFERENCES mount(mountID),
FOREIGN KEY (obsEyepiece) REFERENCES eyepiece(eyepieceID),
FOREIGN KEY (obsLens) REFERENCES lens(lensID),
FOREIGN KEY (obsFilter) REFERENCES filter(filterID),
FOREIGN KEY (obsAccessory) REFERENCES accessory(accessoryID),
FOREIGN KEY (obsAAVSOcomment) REFERENCES AAVSOCommentCode(codeID)
);
-- to report to AAVSO an script (not available yet) can transform this table to a report file


-- auxiliary tables

-- site 
CREATE TABLE site (
siteID text NOT NULL PRIMARY KEY,
siteLongitudeDG real,
siteLatitudeDG real,
siteHeightMT real,
siteTimeZone real,
siteLightPollutionBortle integer,
siteLightPollutionLocal text,
siteSafety integer,
siteTranquility integer,
siteNotes text
);
-- siteLongitudeDG, siteLatitudeDG: referred to WGS84 (GPS)
-- siteTimeZone: time difference with UT
-- siteLightPollutionBortle = https://en.wikipedia.org/wiki/Bortle_scale
-- siteLightPollutionLocal = verbal descriptors about local pollution sources
-- siteSafety, siteTranquility are subjective scales, in a scale from 1 to 10, from very poor to excellent

-- instrument 
CREATE TABLE instrument (
instrumentID text NOT NULL PRIMARY KEY,
instrumentType text,
instrumentBrand text,
instrumentApertureMM real,
instrumentFocalLengthMM real,
instrumentNotes text,
beginLifeSpanDate text,
beginLifeSpanNote text,
endLifeSpanDate text,
endLifeSpanNote text
);
-- beginLifeSpanDate, endLifeSpanDate: expressed as ISO6801 strings: "YYYY-MM-DD"
-- beginLifeSpanNote, endLifeSpanNote: references to seller, buyer, etc

-- mount 
CREATE TABLE mount (
mountID text NOT NULL PRIMARY KEY,
mountType text,
mountBrand text,
mountNotes text,
beginLifeSpanDate text,
beginLifeSpanNote text,
endLifeSpanDate text,
endLifeSpanNote text
);
-- beginLifeSpanDate, endLifeSpanDate: expressed as ISO6801 strings: "YYYY-MM-DD"
-- beginLifeSpanNote, endLifeSpanNote: references to seller, buyer, etc

-- eyepiece 
CREATE TABLE eyepiece (
eyepieceID text NOT NULL PRIMARY KEY,
eyepieceType text,
eyepieceBrand text,
eyepieceModel text,
eyepieceFocalLengthMM real,
eyepieceAfovDG real,
eyepieceEyeReliefMM real,
eyepieceFieldStopMM real,
eyepieceBarrelSizeIN real,
eyepieceBarrelThread boolean,
eyepieceNotes text,
beginLifeSpanDate text,
beginLifeSpanNote text,
endLifeSpanDate text,
endLifeSpanNote text
);
-- beginLifeSpanDate, endLifeSpanDate: expressed as ISO6801 strings: "YYYY-MM-DD"
-- beginLifeSpanNote, endLifeSpanNote: references to seller, buyer, etc

-- lens 
CREATE TABLE lens (
lensID text NOT NULL PRIMARY KEY,
lensType text,
lensBrand text,
lensAmplificationFactor real,
lensBarrelSizeIN real,
lensNotes text,
beginLifeSpanDate text,
beginLifeSpanNote text,
endLifeSpanDate text,
endLifeSpanNote text
);
-- beginLifeSpanDate, endLifeSpanDate: expressed as ISO6801 strings: "YYYY-MM-DD"
-- beginLifeSpanNote, endLifeSpanNote: references to seller, buyer, etc

-- filter 
CREATE TABLE filter (
filterID text NOT NULL PRIMARY KEY,
filterType text,
filterBrand text,
filterBarrelSizeIN real,
filterNotes text,
beginLifeSpanDate text,
beginLifeSpanNote text,
endLifeSpanDate text,
endLifeSpanNote text
);
-- beginLifeSpanDate, endLifeSpanDate: expressed as ISO6801 strings: "YYYY-MM-DD"
-- beginLifeSpanNote, endLifeSpanNote: references to seller, buyer, etc

-- accessory 
CREATE TABLE accessory (
accessoryID text NOT NULL PRIMARY KEY,
accessoryType text,
accessoryBrand text,
accessoryFunction text,
accessoryTo text,
accessoryNotes text,
beginLifeSpanDate text,
beginLifeSpanNote text,
endLifeSpanDate text,
endLifeSpanNote text
);
-- accessoryTo is a relation, points to ID of instrument,mount,etc
-- beginLifeSpanDate, endLifeSpanDate: expressed as ISO6801 strings: "YYYY-MM-DD"
-- beginLifeSpanNote, endLifeSpanNote: references to seller, buyer, etc

-- camera 
CREATE TABLE camera (
cameraID text NOT NULL PRIMARY KEY,
cameraType text,
cameraBrand text,
cameraModel text,
cameraSensorType text,
cameraSensorSizeXpx integer,
cameraSensorSizeYpx integer,
cameraSensorSizeXmm real,
cameraSensorSizeYmm real,
cameraPixelSizeXmicroM real,
cameraPixelSizeYmicroM real,
cameraNotes text,
beginLifeSpanDate text,
beginLifeSpanNote text,
endLifeSpanDate text,
endLifeSpanNote text
);
-- beginLifeSpanDate, endLifeSpanDate: expressed as ISO6801 strings: "YYYY-MM-DD"
-- beginLifeSpanNote, endLifeSpanNote: references to seller, buyer, etc

-- object 
CREATE TABLE object (
objectMyName text NOT NULL PRIMARY KEY,
objectCommonName text,
objectType text,
objectConstellation text,
objectBayer text,
objectFlamsteed integer,
objectHipparcos text,
objectAAVSO text,
objectVarStarType text,
objectMessier integer,
objectNGC integer,
objectIC integer,
objectCaldwell integer,
objectCollinder integer,
objectMelotte integer,
objectOtherCatalogName text,
objectOtherCatalogDsgn text,
objectWiki text,
objectNotes text,
FOREIGN KEY (objectType) REFERENCES objectType(objectType),
FOREIGN KEY (objectConstellation) REFERENCES constellation(constellationID)
);

-- objectType 
CREATE TABLE objectType (
objectType text NOT NULL PRIMARY KEY,
objectTypeDescription text,
objectTypeNotes text
);

-- constellation 
CREATE TABLE constellation (
constellationID text NOT NULL PRIMARY KEY,
constellationFullName text,
constellationGenitive text,
constellationWiki text,
constellationNotes text
);

CREATE TABLE AAVSOCommentCode (
codeID text NOT NULL PRIMARY KEY,
codeMeaning text,
codeNotes text
);

COMMIT;
